
# Type: readonly


If present, slot is read only.  Text explains why

URI: [meta:readonly](https://w3id.org/biolink/biolinkml/meta/readonly)


## Domain and Range

[SlotDefinition](SlotDefinition.md) ->  <sub>OPT</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
